@@ -426,7 +426,9 @@ class Config:
 
     def get_alembic_option(
         self, name: str, default: Optional[str] = None
-    ) -> Union[None, str, list[str], dict[str, str], list[dict[str, str]]]:
+    ) -> Union[
+        None, str, list[str], dict[str, str], list[dict[str, str]], int
+    ]:
         """Return an option from the "[alembic]" or "[tool.alembic]" section
         of the configparser-parsed .ini file (e.g. ``alembic.ini``) or
         toml-parsed ``pyproject.toml`` file.
@@ -455,11 +457,26 @@ class Config:
         else:
             return self._get_toml_config_value(name, default=default)
 
+    def get_alembic_boolean_option(self, name: str) -> bool:
+        if self.file_config.has_option(self.config_ini_section, name):
+            return (
+                self.file_config.get(self.config_ini_section, name) == "true"
+            )
+        else:
+            value = self.toml_alembic_config.get(name, False)
+            if not isinstance(value, bool):
+                raise util.CommandError(
+                    f"boolean value expected for TOML parameter {name!r}"
+                )
+            return value
+
     def _get_toml_config_value(
         self, name: str, default: Optional[Any] = None
-    ) -> Union[None, str, list[str], dict[str, str], list[dict[str, str]]]:
+    ) -> Union[
+        None, str, list[str], dict[str, str], list[dict[str, str]], int
+    ]:
         USE_DEFAULT = object()
-        value: Union[None, str, list[str], dict[str, str]] = (
+        value: Union[None, str, list[str], dict[str, str], int] = (
             self.toml_alembic_config.get(name, USE_DEFAULT)
         )
         if value is USE_DEFAULT:
@@ -482,8 +499,12 @@ class Config:
                     "dict[str, str]",
                     {k: v % (self.toml_args) for k, v in value.items()},
                 )
+            elif isinstance(value, int):
+                return value
             else:
-                raise util.CommandError("unsupported TOML value type")
+                raise util.CommandError(
+                    f"unsupported TOML value type for key: {name!r}"
+                )
         return value
 
     @util.memoized_property
@@ -787,6 +808,17 @@ class CommandLine:
                 "environment and version locations",
             ),
         ),
+        "check_heads": (
+            "-c",
+            "--check-heads",
+            dict(
+                action="store_true",
+                help=(
+                    "Check if all head revisions are applied to the database. "
+                    "Exit with an error code if this is not the case."
+                ),
+            ),
+        ),
     }
     _POSITIONAL_OPTS = {
         "directory": dict(help="location of scripts directory"),
