@@ -55,6 +55,7 @@ from alembic.testing.suite._autogen_fixtures import _default_name_filters
 from alembic.testing.suite._autogen_fixtures import _default_object_filters
 from alembic.testing.suite._autogen_fixtures import AutogenFixtureTest
 from alembic.testing.suite._autogen_fixtures import AutogenTest
+from alembic.testing.suite._autogen_fixtures import ModelOne
 from alembic.util import CommandError
 
 # TODO: we should make an adaptation of CompareMetadataToInspectorTest that is
@@ -315,104 +316,6 @@ class AutogenDefaultSchemaIsNoneTest(AutogenFixtureTest, TestBase):
         eq_(len(diffs), 0)
 
 
-class ModelOne:
-    __requires__ = ("unique_constraint_reflection",)
-
-    schema = None
-
-    @classmethod
-    def _get_db_schema(cls):
-        schema = cls.schema
-
-        m = MetaData(schema=schema)
-
-        Table(
-            "user",
-            m,
-            Column("id", Integer, primary_key=True),
-            Column("name", String(50)),
-            Column("a1", Text),
-            Column("pw", String(50)),
-            Index("pw_idx", "pw"),
-        )
-
-        Table(
-            "address",
-            m,
-            Column("id", Integer, primary_key=True),
-            Column("email_address", String(100), nullable=False),
-        )
-
-        Table(
-            "order",
-            m,
-            Column("order_id", Integer, primary_key=True),
-            Column(
-                "amount",
-                Numeric(8, 2),
-                nullable=False,
-                server_default=text("0"),
-            ),
-            CheckConstraint("amount >= 0", name="ck_order_amount"),
-        )
-
-        Table(
-            "extra",
-            m,
-            Column("x", CHAR),
-            Column("uid", Integer, ForeignKey("user.id")),
-        )
-
-        return m
-
-    @classmethod
-    def _get_model_schema(cls):
-        schema = cls.schema
-
-        m = MetaData(schema=schema)
-
-        Table(
-            "user",
-            m,
-            Column("id", Integer, primary_key=True),
-            Column("name", String(50), nullable=False),
-            Column("a1", Text, server_default="x"),
-        )
-
-        Table(
-            "address",
-            m,
-            Column("id", Integer, primary_key=True),
-            Column("email_address", String(100), nullable=False),
-            Column("street", String(50)),
-            UniqueConstraint("email_address", name="uq_email"),
-        )
-
-        Table(
-            "order",
-            m,
-            Column("order_id", Integer, primary_key=True),
-            Column(
-                "amount",
-                Numeric(10, 2),
-                nullable=True,
-                server_default=text("0"),
-            ),
-            Column("user_id", Integer, ForeignKey("user.id")),
-            CheckConstraint("amount > -1", name="ck_order_amount"),
-        )
-
-        Table(
-            "item",
-            m,
-            Column("id", Integer, primary_key=True),
-            Column("description", String(100)),
-            Column("order_id", Integer, ForeignKey("order.order_id")),
-            CheckConstraint("len(description) > 5"),
-        )
-        return m
-
-
 class AutogenerateDiffTest(ModelOne, AutogenTest, TestBase):
     __only_on__ = "sqlite"
 
@@ -1783,6 +1686,7 @@ class OrigObjectTest(TestBase):
             Column("x", Integer()),
         )
         self.ix = Index("ix1", t.c.id)
+        self.ix_unique = Index("ix2", t.c.id, unique=True)
         fk = ForeignKeyConstraint(["t_id"], ["t.id"])
         q = Table("q", m, Column("t_id", Integer()), fk)
         self.table = t
@@ -1905,6 +1809,14 @@ class OrigObjectTest(TestBase):
         eq_(op.to_index(), schemacompare.CompareIndex(self.ix))
         eq_(op.reverse().to_index(), schemacompare.CompareIndex(self.ix))
 
+    def test_create_unique_index(self):
+        op = ops.CreateIndexOp.from_index(self.ix_unique)
+        eq_(op.to_index(), schemacompare.CompareIndex(self.ix_unique))
+        eq_(
+            op.reverse().to_index(),
+            schemacompare.CompareIndex(self.ix_unique),
+        )
+
 
 class MultipleMetaDataTest(AutogenFixtureTest, TestBase):
     def test_multiple(self):
@@ -1998,3 +1910,98 @@ class MultipleMetaDataTest(AutogenFixtureTest, TestBase):
             [m1a, m1b],
             [m2a, m2b],
         )
+
+
+class AutogenFKTest(AutogenFixtureTest, TestBase):
+    """Test foreign key constraint handling in autogenerate."""
+
+    __backend__ = True
+    __requires__ = ("foreign_key_constraint_reflection",)
+
+    @testing.variation("case", ["uppercase", "lowercase"])
+    @testing.variation("use_naming_convention", [True, False])
+    @config.requirements.foreign_key_name_reflection
+    def test_drop_fk_with_mixed_case_name(self, case, use_naming_convention):
+        """Test #1743"""
+        if case.uppercase:
+            fk_pattern = (
+                "FK_%(table_name)s_%(column_0_name)s_%(referred_table_name)s"
+            )
+            expected_name = "FK_child_parent_id_parent"
+        else:
+            fk_pattern = (
+                "fk_%(table_name)s_%(column_0_name)s_%(referred_table_name)s"
+            )
+            expected_name = "fk_child_parent_id_parent"
+
+        if use_naming_convention:
+            m1 = MetaData(naming_convention={"fk": fk_pattern})
+        else:
+            m1 = MetaData()
+
+        Table(
+            "parent",
+            m1,
+            Column("id", Integer, primary_key=True),
+            Column("name", String(50)),
+        )
+
+        c = Table(
+            "child",
+            m1,
+            Column("id", Integer, primary_key=True),
+            Column("name", String(50)),
+            Column("parent_id", Integer),
+            (
+                ForeignKeyConstraint(["parent_id"], ["parent.id"])
+                if use_naming_convention
+                else ForeignKeyConstraint(
+                    ["parent_id"], ["parent.id"], name=expected_name
+                )
+            ),
+        )
+
+        eq_(
+            [
+                fk
+                for fk in c.constraints
+                if isinstance(fk, ForeignKeyConstraint)
+            ][0].name,
+            expected_name,
+        )
+
+        if use_naming_convention:
+            m2 = MetaData(naming_convention={"fk": fk_pattern})
+        else:
+            m2 = MetaData()
+
+        Table(
+            "parent",
+            m2,
+            Column("id", Integer, primary_key=True),
+            Column("name", String(50)),
+        )
+
+        Table(
+            "child",
+            m2,
+            Column("id", Integer, primary_key=True),
+            Column("name", String(50)),
+            Column("parent_id", Integer),
+        )
+
+        diffs = self._fixture(m1, m2)
+
+        # Should detect the FK removal
+        eq_(len(diffs), 1, f"Expected 1 diff, got {len(diffs)}: {diffs}")
+
+        # Verify it's a remove_fk operation with the correct name
+        self._assert_fk_diff(
+            diffs[0],
+            "remove_fk",
+            "child",
+            ["parent_id"],
+            "parent",
+            ["id"],
+            name=expected_name,
+        )
